centroid.sign: Positive and Negative View Centroid

View source: R/ac_ranking.R

centroid.signR Documentation

Positive and Negative View Centroid

Description

Compute the centroid for expressing a view on assets with positive or negative expected returns

Usage

centroid.sign(positive, negative, simulations = 1000)

Arguments

positive

a vector of the index of assets with positive expected return in ascending order

negative

a vector of the index of assets with negative expected return in ascending order.

simulations

number of simulations

Value

the centroid vector

Author(s)

Ross Bennett

Examples

# Express a view that
# R_1 < R_2 < 0 < R_3 < R_4
centroid.sign(c(1, 2), c(4, 3))

PortfolioAnalytics documentation built on April 10, 2026, 9:07 a.m.